@@ -41,6 +41,7 @@ IGNORE
 """
 import os
 import sys
+import warnings
 import scipy as sci
 import numpy as np
 from .spectrum import Spectrum
@@ -525,6 +526,14 @@ def trimspectrum(x: list, y: list, left: float, right: float, outside: bool = Fa
     :return: new spectrum
     :rtype: tuple of list
     """
+    if isinstance(x, np.ndarray) and isinstance(np.ndarray):
+        return slice_array(
+            y,
+            x,
+            left,
+            right,
+            outside=outside,
+        )
     # find indicies
     l = locate_in_list(x, left, 'greater')
     r = locate_in_list(x, right, 'lesser')
@@ -1235,3 +1244,76 @@ def strtolist(string):
         except ValueError:
             out.append(float(temp))
     return out
+
+
+def check_integer(val, name):
+    """
+    This function checks that the supplied values are integers greater than 1
+
+    A integer value that is non-negative is required for the summing function.
+    Please check your input value.
+    """
+    if type(val) != list and type(val) != tuple:  # if only one value given for n
+        val = [val]
+    for num in val:
+        if type(num) != int:
+            raise ValueError(f'The {name} value ({num}) is not an integer.')
+        if num < 1:
+            raise ValueError(f'The {name} value ({num}) is less than 1.')
+    return val
+
+
+def slice_array(value_array: np.ndarray,
+                check_array: np.ndarray = True,
+                lower_bound: float = None,
+                upper_bound: float = None,
+                outside: bool = False,
+                ) -> np.ndarray:
+    """
+    Slices a numpy ndarray with the provided conditions
+
+    :param value_array: array of values to integrate
+    :param check_array: array of values to check against (the value of the check array must be between the lower and
+        upper bounds
+    :param lower_bound: lower bound for the check array
+    :param upper_bound: upper bound for the check array
+    :param outside: Whether to include the next point outside of the trimmed spectrum. This provides continuity if the
+        spectrum is to be used for image generation.
+    :return: sliced x,y array
+    """
+    # todo support outside argument
+    if outside:
+        warnings.warn(
+            'the outside argument is not supported by the slice_array function, convert to list and use trimspectrum',
+            stacklevel=2,
+        )
+    if lower_bound is not None:
+        if upper_bound is None:  # todo accept single condition
+            raise ValueError(f'upper bound must also be specified')
+        truth_array = (lower_bound <= check_array) & (check_array <= upper_bound)
+    else:
+        truth_array = check_array
+    # todo see if there's a more efficient way to do this
+    out = np.ndarray((2, truth_array.sum()))
+    out[0] = check_array[truth_array]
+    out[1] = value_array[truth_array]
+    return out
+
+
+def integrate_numpy(value_array: np.ndarray,
+                    check_array: np.ndarray = True,
+                    lower_bound: float = None,
+                    upper_bound: float = None,
+                    ) -> float:
+    """
+    Integrates a value array with the provided conditions.
+
+    :param value_array: array of values to integrate
+    :param check_array: array of values to check against (the value of the check array must be between the lower and
+        upper bounds
+    :param lower_bound: lower bound for the check array
+    :param upper_bound: upper bound for the check array
+    :return: integral (sum)
+    """
+    _, y = slice_array(value_array, check_array, lower_bound, upper_bound)
+    return y.sum()
